# Bio-ensemblrest
# 
# Copyright (C) 2015
#
# author: Natapol Pornputtapong <natapol.por@gmail.com>
#
# Documentation: Natapol Pornputtapong (RDoc'd and embellished by William Webber)
#

# raise "Please, use ruby 1.9.0 or later." if RUBY_VERSION < "1.9.0"

module EnsemblREST

	module Comparative
	
		module_function
		
		# Retrieves a gene tree dump for a gene tree stable identifier
		# 
		# @param [String] id An Ensembl genetree ID
		# @param [Hash] options Optional arguments for the service please goto http://rest.ensembl.org/documentation/info/genetree
		# @return [JSON] a gene tree
		def genetree(id, options = {})
			return EnsemblREST.get("genetree/id/#{id}", {format: 'json'}.merge(options))
		end
		
		# Retrieves a gene tree that contains the stable identifier
		# 
		# @param [String] id An Ensembl stable ID
		# @param [Hash] options Optional arguments for the service please goto http://rest.ensembl.org/documentation/info/genetree_member_id
		# @return [JSON] gene trees
		def genetree_member_id(id, options = {})
			return EnsemblREST.get("genetree/member/id/#{id}", {format: 'json'}.merge(options))
		end
		
		# Retrieves a gene tree containing the gene identified by a symbol
		# 
		# @param [String] symbol Symbol or display name of a gene
		# @param [String] species Species name/alias
		# @param [Hash] options Optional arguments for the service please goto http://rest.ensembl.org/documentation/info/genetree_member_symbol
		# @return [JSON] gene trees
		def genetree_member_symbol(symbol, species = 'human', options = {})
			return EnsemblREST.get("genetree/member/symbol/#{species}/#{symbol}", {format: 'json'}.merge(options))
		end
		
		# Retrieves genomic alignments as separate blocks based on a region and species
		# 
		# @param [String] region Query region. A maximum of 10Mb is allowed to be requested at any one time
		# @param [String] species Species name/alias
		# @param [Hash] options Optional arguments for the service please goto http://rest.ensembl.org/documentation/info/genomic_alignment_region
		# @return [JSON] an alignment
		def genomic_alignment_region(region, species = 'human', options = {})
			return EnsemblREST.get("alignment/region/#{species}/#{region}", {format: 'json'}.merge(options))
		end
		
		# Retrieves homology information (orthologs) by Ensembl gene id
		# 
		# @param [String] id An Ensembl stable ID
		# @param [Hash] options Optional arguments for the service please goto http://rest.ensembl.org/documentation/info/homology_ensemblgene
		# @return [JSON] a homology information
		def homology_ensemblgene(id, options = {})
			return EnsemblREST.get("homology/id/#{id}", {format: 'json'}.merge(options))
		end
		
		# Retrieves homology information (orthologs) by symbol
		# 
		# @param [String] symbol Symbol or display name of a gene
		# @param [String] species Species name/alias
		# @param [Hash] options Optional arguments for the service please goto http://rest.ensembl.org/documentation/info/homology_symbol
		# @return [JSON] gene trees
		def homology_symbol(symbol, species = 'human', options = {})
			return EnsemblREST.get("homology/symbol/#{species}/#{symbol}", {format: 'json'}.merge(options))
		end
	end
end