# Bio-ensemblrest
# 
# Copyright (C) 2015
#
# author: Natapol Pornputtapong <natapol.por@gmail.com>
#
# Documentation: Natapol Pornputtapong (RDoc'd and embellished by William Webber)
#

# raise "Please, use ruby 1.9.0 or later." if RUBY_VERSION < "1.9.0"

module EnsemblREST
	module Lookup
		module_function
		
		# Find the species and database for a symbol in a linked external database
		# 
		# @param [String] symbol A name or symbol from an annotation source has been linked to a genetic feature
		# @param [String] species Species name/alias
		# @param [Hash] options Optional arguments for the service please goto http://rest.ensembl.org/documentation/info/symbol_lookup
		# @return [JSON] Cross references
		def symbol(symbol, species = 'human', options = {})
			return EnsemblREST.get("lookup/symbol/#{species}/#{symbol}", {format: 'json'}.merge(options))
		end
		
		# Find the species and database for a single identifier
		# 
		# @param [String] id An Ensembl Stable ID
		# @param [Hash] options Optional arguments for the service please goto http://rest.ensembl.org/documentation/info/lookup
		# @return [JSON] Cross references
		def id(id, options = {})
			return EnsemblREST.get("lookup/id/#{id}", {format: 'json'}.merge(options))
		end
		
		# Find the species and database for a set of symbols in a linked external database. Unknown symbols are omitted from the response.
		# 
		# @param [String] symbols An array of names or symbols from an annotation source has been linked to a genetic feature
		# @param [String] species Species name/alias
		# @param [Hash] options Optional arguments for the service please goto http://rest.ensembl.org/documentation/info/symbol_post
		# @return [JSON] Cross references
		def symbol_post(symbols, species = 'human', options = {})
			return EnsemblREST.post("lookup/symbol/#{species}", {'symbols' => symbols}, {format: 'json'}.merge(options))
		end
		
		# Find the species and database for several identifiers. IDs that are not found are returned with no data.
		# 
		# @param [String] ids Ensembl Stable IDs
		# @param [Hash] options Optional arguments for the service please goto http://rest.ensembl.org/documentation/info/lookup_post
		# @return [JSON] Cross references
		def id_post(ids, options = {})
			return EnsemblREST.post("lookup/id", {'ids' => ids}, {format: 'json'}.merge(options))
		end
	end
end