# 
# Bio-ensemblrest
# Copyright (C) 2014
#
# author: Natapol Pornputtapong <natapol.por@gmail.com>
#
# Documentation: Natapol Pornputtapong (RDoc'd and embellished by William Webber)
#

# raise "Please, use ruby 1.9.0 or later." if RUBY_VERSION < "1.9.0"

module EnsemblREST
	
	module Map
		module_function
		
		# Convert from cDNA coordinates to genomic coordinates. Output reflects forward orientation coordinates as returned from the Ensembl API.
		# 
		# @param [String] id An Ensembl stable ID
		# @param [String] region Query region
		# @param [Hash] options Optional arguments for the service please goto http://rest.ensembl.org/documentation/info/assembly_cdna
		# @return [JSON] genomic coordinates
		def cdna(id, region, options = {})
			return EnsemblREST.get("map/cdna/#{id}/#{region}", {format: 'json'}.merge(options))
		end
		
		# Convert from CDS coordinates to genomic coordinates. Output reflects forward orientation coordinates as returned from the Ensembl API.
		# 
		# @param [String] id An Ensembl stable ID
		# @param [String] region Query region
		# @param [Hash] options Optional arguments for the service please goto http://rest.ensembl.org/documentation/info/assembly_cds
		# @return [JSON] genomic coordinates
		def cds(id, region, options = {})
			return EnsemblREST.get("map/cds/#{id}/#{region}", {format: 'json'}.merge(options))
		end
		
		# Convert the co-ordinates of one assembly to another
		# 
		# @param [String] region Query region
		# @param [String] asm_one Version of the input assembly
		# @param [String] asm_two Version of the output assembly
		# @param [String] species Species name/alias
		# @param [Hash] options Optional arguments for the service please goto http://rest.ensembl.org/documentation/info/assembly_map
		# @return [JSON] genomic coordinates
		def map(region, asm_one, asm_two, species = 'human', options = {})
			return EnsemblREST.get("map/#{species}/#{asm_one}/#{region}/#{asm_two}", {format: 'json'}.merge(options))
		end
		
		# Convert from protein (translation) coordinates to genomic coordinates. Output reflects forward orientation coordinates as returned from the Ensembl API.
		# 
		# @param [String] id An Ensembl stable ID
		# @param [String] region Query region
		# @param [Hash] options Optional arguments for the service please goto http://rest.ensembl.org/documentation/info/assembly_translation
		# @return [JSON] genomic coordinates
		def translation(id, region, options = {})
			return EnsemblREST.get("map/translation/#{id}/#{region}", {format: 'json'}.merge(options))
		end
	end
end