# Bio-ensemblrest
# 
# Copyright (C) 2015
#
# author: Natapol Pornputtapong <natapol.por@gmail.com>
#
# Documentation: Natapol Pornputtapong (RDoc'd and embellished by William Webber)
#

# raise "Please, use ruby 1.9.0 or later." if RUBY_VERSION < "1.9.0"

module EnsemblREST
	
	module Ontology
	
		module_function
		
		# Reconstruct the entire ancestry of a term from is_a and part_of relationships
		# 
		# @param [String] id An ontology term identifier
		# @param [Hash] options Optional arguments for the service please goto http://rest.ensembl.org/documentation/info/ontology_ancestors
		# @return [JSON] the entire ancestry of a term
		def ancestors(id, options = {})
			return EnsemblREST.get("ontology/ancestors/#{id}", {format: 'json'}.merge(options))
		end
		
		# Reconstruct the entire ancestry of a term from is_a and part_of relationships.
		# 
		# @param [String] id An ontology term identifier
		# @param [Hash] options Optional arguments for the service please goto http://rest.ensembl.org/documentation/info/ontology_ancestors_chart
		# @return [JSON] the entire ancestry of a term
		def ancestors_chart(id, options = {})
			return EnsemblREST.get("ontology/ancestors/chart/#{id}", {format: 'json'}.merge(options))
		end
		
		# Find all the terms descended from a given term. By default searches are conducted within the namespace of the given identifier
		# 
		# @param [String] id An ontology term identifier
		# @param [Hash] options Optional arguments for the service please goto http://rest.ensembl.org/documentation/info/ontology_descendants
		# @return [JSON] the terms descended from a given term
		def descendants(id, options = {})
			return EnsemblREST.get("ontology/descendants/#{id}", {format: 'json'}.merge(options))
		end
		
		# Search for an ontological term by its namespaced identifier
		# 
		# @param [String] name An ontology term identifier
		# @param [Hash] options Optional arguments for the service please goto http://rest.ensembl.org/documentation/info/ontology_id
		# @return [JSON] an ontological term
		def id(name, options = {})
			return EnsemblREST.get("ontology/id/#{name}", {format: 'json'}.merge(options))
		end
		
		# Search for a list of ontological terms by their name
		# 
		# @param [String] name An ontology name. SQL wildcards are supported
		# @param [Hash] options Optional arguments for the service please goto http://rest.ensembl.org/documentation/info/ontology_name
		# @return [JSON] a list of ontological terms
		def name(name, options = {})
			return EnsemblREST.get("ontology/name/#{URI.escape(name)}", {format: 'json'}.merge(options))
		end
	end
	
	module Taxonomy
	
		module_function
	
		# Return the taxonomic classification of a taxon node
		# 
		# @param [String] id A taxon identifier. Can be a NCBI taxon id or a name
		# @param [Hash] options Optional arguments for the service please goto http://rest.ensembl.org/documentation/info/taxonomy_classification
		# @return [JSON] the taxonomic classification
		def classification(id, options = {})
			return EnsemblREST.get("taxonomy/classification/#{id}", {format: 'json'}.merge(options))
		end
		
		# Search for a taxonomic term by its identifier or name
		# 
		# @param [String] id A taxon identifier. Can be a NCBI taxon id or a name
		# @param [Hash] options Optional arguments for the service please goto http://rest.ensembl.org/documentation/info/taxonomy_id
		# @return [JSON] the taxonomic classification
		def id(id, options = {})
			return EnsemblREST.get("taxonomy/id/#{id}", {format: 'json'}.merge(options))
		end
		
		# Search for a taxonomic id by a non-scientific name
		# 
		# @param [String] name A non-scientific species name. Can include SQL wildcards
		# @param [Hash] options Optional arguments for the service please goto http://rest.ensembl.org/documentation/info/taxonomy_name
		# @return [JSON] the taxonomic classification
		def name(name, options = {})
			return EnsemblREST.get("taxonomy/name/#{URI.escape(name)}", {format: 'json'}.merge(options))
		end
	end
end