# Copyright (C) 2015
#
# author: Natapol Pornputtapong <natapol.por@gmail.com>
#
# Documentation: Natapol Pornputtapong (RDoc'd and embellished by William Webber)
#

# raise "Please, use ruby 1.9.0 or later." if RUBY_VERSION < "1.9.0"

module EnsemblREST

	module Overlap
		module_function
		
		# Request multiple types of sequence by a list of regions.
		# 
		# @param [Array] region Query regions. A maximum of 10Mb is allowed to be requested at any one time
		# @param [Array] features The type of feature to retrieve. Multiple values are accepted. Array of gene, transcript, cds, exon, repeat, simple, misc, variation, somatic_variation, 
		# structural_variation, somatic_structural_variation, constrained, regulatory, segmentation, motif, chipseq, array_probe
		# @param [String] species Species name/alias
		# @param [Hash] options Optional arguments for the service please goto http://rest.ensembl.org/documentation/info/overlap_region
		# @return [JSON] Requested response
		def region(region, features = [], species = 'human', options = {})
			return EnsemblREST.get("overlap/region/#{species}/#{region}", {format: 'json', feature: features}.merge(options))
		end
		
		# Retrieves features (e.g. genes, transcripts, variations etc.) that overlap a region defined by the given identifier.
		# 
		# @param [String] id An Ensembl stable ID
		# @param [Array] features The type of feature to retrieve. Multiple values are accepted. Array of gene, transcript, cds, exon, repeat, simple, misc, variation, somatic_variation, 
		# structural_variation, somatic_structural_variation, constrained, regulatory, segmentation, motif, chipseq, array_probe
		# @param [Hash] options Optional arguments for the service please goto http://rest.ensembl.org/documentation/info/overlap_id
		# @return [JSON] Requested response
		def id(id, features = [], options = {})
			return EnsemblREST.get("overlap/id/#{id}", {format: 'json', feature: features}.merge(options))
		end
		
		# Retrieve features related to a specific Translation as described by its stable ID (e.g. domains, variations).
		# 
		# @param [String] id An Ensembl stable ID
		# @param [Hash] options Optional arguments for the service please goto http://rest.ensembl.org/documentation/info/overlap_translation
		# @return [JSON] Requested response
		def translation(id, options = {})
			return EnsemblREST.get("overlap/translation/#{id}", {format: 'json'}.merge(options))
		end
	end
end
