# 
# Bio-ensemblrest
# Copyright (C) 2014
#
# author: Natapol Pornputtapong <natapol.por@gmail.com>
#
# Documentation: Natapol Pornputtapong (RDoc'd and embellished by William Webber)
#

# raise "Please, use ruby 1.9.0 or later." if RUBY_VERSION < "1.9.0"

module EnsemblREST
	
	module Sequence
		module_function
		
		# Request multiple types of sequence by stable identifier.
		# 
		# @param [String] id An Ensembl stable ID
		# @param [Hash] options Optional arguments for the service please goto http://rest.ensembl.org/documentation/info/sequence_id
		# @return [FastaFormat] requested sequence
		def id(id, options = {})
			return EnsemblREST.get("sequence/id/#{id}", {format: 'fasta'}.merge(options))
		end
		
		# Returns the genomic sequence of the specified region of the given species.
		# 
		# @param [String] regionQuery region. A maximum of 10Mb is allowed to be requested at any one time
		# @param [String] species Species name/alias
		# @param [Hash] options Optional arguments for the service please goto http://rest.ensembl.org/documentation/info/sequence_region
		# @return [FastaFormat] requested sequence
		def region(region, species = 'human', options = {})
			return EnsemblREST.get("sequence/region/#{species}/#{region}", {format: 'fasta'}.merge(options))
		end
		
		# Request multiple types of sequence by a stable identifier list.
		# 
		# @param [Array] ids Ensembl stable IDs
		# @param [Hash] options Optional arguments for the service please goto http://rest.ensembl.org/documentation/info/sequence_id_post
		# @return [JSON] Requested response
		def id_post(ids, options = {})
			return EnsemblREST.post("sequence/id", {"ids" => ids}, {format: 'json'}.merge(options))
		end
		
		# Request multiple types of sequence by a list of regions.
		# 
		# @param [Array] regions Query regions. A maximum of 10Mb is allowed to be requested at any one time
		# @param [String] species Species name/alias
		# @param [Hash] options Optional arguments for the service please goto http://rest.ensembl.org/documentation/info/sequence_region_post
		# @return [JSON] Requested response
		def region_post(regions, species = 'human', options = {})
			return EnsemblREST.post("sequence/region/#{species}", {"regions" => regions}, {format: 'json'}.merge(options))
		end
	end
end