# Bio-ensemblrest
# 
# Copyright (C) 2015
#
# author: Natapol Pornputtapong <natapol.por@gmail.com>
#
# Documentation: Natapol Pornputtapong (RDoc'd and embellished by William Webber)
#

# raise "Please, use ruby 1.9.0 or later." if RUBY_VERSION < "1.9.0"

module EnsemblREST
	
	module GA4GH
		module_function
		
		# Return a list of sets of genotype calls for specific samples in GA4GH format
		# 
		# @param [Hash] options Optional arguments for the service please goto http://rest.ensembl.org/documentation/info/gacallSet
		# @return [JSON] a list of sets of genotype calls for specific samples
		def gacallSet(options = {})
			return EnsemblREST.post("ga4gh/callsets/search", {}, {format: 'json'}.merge(options))
		end
		
		# Return variant call information in GA4GH format for a region on a reference sequence
		#
		# @param [Integer] start Start position of region (zero-based, inclusive)
		# @param [Integer] stop End position of region (zero-based, exclusive)
		# @param [String] referenceName Reference sequence name
		# @param [Array] variantSetIds Return variant data for specific variantSets
		# @param [Hash] options Optional arguments for the service please goto http://rest.ensembl.org/documentation/info/gavariants
		# @return [JSON] variant call information in GA4GH format
		def gavariants(start, stop, referenceName, variantSetIds, options = {})
			return EnsemblREST.post("ga4gh/variants/search", {"variantSetIds" => variantSetIds, "referenceName" => referenceName,"start" => start ,"end" => stop}, {format: 'json'}.merge(options))
		end
		
		# Return a list of variant sets in GA4GH format
		# 
		# @param [Hash] options Optional arguments for the service please goto http://rest.ensembl.org/documentation/info/gavariantset
		# @return [JSON] a list of variant sets in GA4GH format
		def gavariantset(options = {})
			return EnsemblREST.post("ga4gh/variantsets/search", {}, {format: 'json'}.merge(options))
		end
	end
end