# Bio-ensemblrest
# 
# Copyright (C) 2015
#
# author: Natapol Pornputtapong <natapol.por@gmail.com>
#
# Documentation: Natapol Pornputtapong (RDoc'd and embellished by William Webber)
#

# raise "Please, use ruby 1.9.0 or later." if RUBY_VERSION < "1.9.0"

module EnsemblREST

	module VEP
	
		module_function
		
		# Fetch variant consequences
		# 
		# @param [String] allele Variation allele, Example Values: 'C', 'DUP'
		# @param [String] region Query region. Example Values: '9:22125503-22125502:1', '7:100318423-100321323:1'
		# @param [String] species Species name/alias
		# @param [Hash] options Optional arguments for the service please goto http://rest.ensembl.org/documentation/info/vep_region_get
		# @return [JSON] Variants consequences
		def region_get(allele, region, species = 'human', options = {})
			return EnsemblREST.get("vep/#{species}/region/#{region}/#{allele}", {format: 'json'}.merge(options))
		end
		
		# Fetch variant consequences based on a variation identifier
		# 
		# @param [String] id Query ID. Supports dbSNP, COSMIC and HGMD identifiers
		# @param [String] species Species name/alias
		# @param [Hash] options Optional arguments for the service please goto http://rest.ensembl.org/documentation/info/vep_region_get
		# @return [JSON] Variants consequences
		def id_get(id, species = 'human', options = {})
			return EnsemblREST.get("vep/#{species}/id/#{id}", {format: 'json'}.merge(options))
		end
		
		# Fetch variant consequences based on a HGVS notation
		# 
		# @param [String] hgvs_notation HGVS notation. May be genomic (g), coding (c) or protein (p), with reference to chromosome name, gene name, transcript ID or protein ID.
		# @param [String] species Species name/alias
		# @param [Hash] options Optional arguments for the service please goto http://rest.ensembl.org/documentation/info/vep_hgvs_get
		# @return [JSON] Variants consequences
		def hgvs_get(hgvs_notation, species = 'human', options = {})
			return EnsemblREST.get("vep/#{species}/hgvs/#{hgvs_notation}", {format: 'json'}.merge(options))
		end
		
		# Fetch variant consequences for multiple ids
		# 
		# @param [Array] ids Query IDs. Supports dbSNP, COSMIC and HGMD identifiers
		# @param [String] species Species name/alias
		# @param [Hash] options Optional arguments for the service please goto http://rest.ensembl.org/documentation/info/vep_id_post
		# @return [JSON] Variants consequences
		def id_post(ids, species = 'human', options = {})
			return EnsemblREST.post("vep/#{species}/id", {"ids" => ids}, {format: 'json'}.merge(options))
		end
		
		# Fetch variant consequences for multiple regions
		# 
		# @param [Array] variants input lines for VEP. Example Values: ["21 26960070 rs116645811 G A . . .", "21 26965148 rs1135638 G A . . ." ]
		# @param [String] species Species name/alias
		# @param [Hash] options Optional arguments for the service please goto http://rest.ensembl.org/documentation/info/vep_region_get
		# @return [JSON] Variants consequences
		def region_post(variants, species = 'human', options = {})
			return EnsemblREST.post("vep/#{species}/region", {"variants" => variants}, {format: 'json'}.merge(options))
		end
	end
end
